@@ -1,6 +1,13 @@
 ##' Create a graded response model
 ##'
-##' This function instantiates a graded response model.
+##' For outcomes k in 0 to K, slope vector a, intercept vector c, and latent ability vector theta,
+##' the response probability function is
+##' \deqn{\mathrm P(\mathrm{pick}=0|a,c,\theta) = 1- \mathrm P(\mathrm{pick}=1|a,c_1,\theta)
+##' }{P(pick=0|a,c,th) = 1-P(pick=1|a,c_1,th)}
+##' \deqn{\mathrm P(\mathrm{pick}=k|a,c,\theta) = \frac{1}{1+\exp(-(a\theta + c_k))} - \frac{1}{1+\exp(-(a\theta + c_{k+1}))}
+##' }{P(pick=k|a,c,th) = 1/(1+exp(-(a th + c_k))) - 1/(1+exp(-(a th + c_(k+1))))}
+##' \deqn{\mathrm P(\mathrm{pick}=K|a,c,\theta) = \frac{1}{1+\exp(-(a\theta + c_K))}
+##' }{P(pick=K|a,c,th) = 1/(1+exp(-(a th + c_K)))}
 ##'
 ##' The graded response model was designed for a item with a series of
 ##' dependent parts where a higher score implies that easier parts of
@@ -35,17 +42,13 @@ rpf.grm <- function(outcomes=2, factors=1, multidimensional=TRUE) {
   m
 }
 
-### 1dim
-
-setMethod("rpf.rparam", signature(m="rpf.1dim.graded"),
-          function(m) {
-              a <- rlnorm(1, meanlog=0, sdlog=.5)
-              b <- sort(rnorm(m@outcomes-1))
-              c(a=a,b=b)
-          })
-
 ### mdim
 
+setMethod("rpf.modify", signature(m="rpf.mdim.graded", factors="numeric"),
+          function(m, factors) {
+              rpf.grm(m@outcomes, factors)
+          })
+
 setMethod("rpf.rparam", signature(m="rpf.mdim.graded"),
           function(m) {
               a <- rlnorm(m@factors, meanlog=0, sdlog=.5)
