@@ -14,26 +14,28 @@ theta <- rnorm(2)
 theta.2d <- array(dim=c(2,3), data=rnorm(6))
 
 checkDim <- function(item, param) {
-    expect_equal(length(param), rpf.numParam(item), class(item))
-    expect_equal(length(rpf.rparam(item)), rpf.numParam(item), class(item))
+    expect_equal(length(param), rpf.numParam(item), info=class(item))
+    expect_equal(length(rpf.rparam(item)), rpf.numParam(item), info=class(item))
 }
 
 test_that("3PL ICC", {
   i1 <- rpf.drm()
   i1.p <- rpf.rparam(i1)
-  i1.p[-1] <- 1  # plink doesn't do upper bounds
+  i1.p['u'] <- 1  # plink doesn't do upper bounds
+  i2.p <- i1.p[1:3]
+  i2.p[2] <-i2.p[2] / -i2.p[1]  # traditional parameterization
   checkDim(i1,i1.p)
-  expect_equal(drm(t(i1.p[1:3]), theta, 1)@prob[,2],
-               rpf.prob(i1, i1.p, theta)[,2],
-               "3PL")
+  expect_equal(drm(t(i2.p), theta, 1)@prob[,2],
+               rpf.prob(i1, i1.p, theta)[2,],
+               info="3PL")
 
   m1 <- rpf.drm(factors=2)
   m1.p <- rpf.rparam(m1)
-  m1.p[-1] <- 1  # plink doesn't do upper bounds
+  m1.p['u'] <- 1  # plink doesn't do upper bounds
   checkDim(m1,m1.p)
   expect_equivalent(rpf.prob(m1, m1.p, theta.2d)[2,],
                     drm(t(m1.p[1:4]), t(theta.2d), dimensions=2)@prob[,3],
-                    "M3PL")
+                    info="M3PL")
 })
 
 # Rewrite in terms of nominal model TODO
@@ -64,7 +66,7 @@ i4.p <- rpf.rparam(i4)
 checkDim(i4,i4.p)
 expect_equivalent(rpf.prob(i4, i4.p, theta.2d),
                    as.matrix(nrm(x=i4.plink,cat=3, factors=2, t(theta.2d))@prob[,-1:-2]),
-                   "NRM")
+                   info="NRM")
 }
 
 # Not implemented
@@ -89,5 +91,5 @@ test_that("GRM ICC", {
   checkDim(i7,i7.p)
   expect_equivalent(rpf.prob(i7, i7.p, theta.2d),
                     t(grm(t(i7.p),dimensions=2,cat=3,t(theta.2d),catprob=TRUE)@prob[,-1:-2]),
-                    "M-GRM")
+                    info="M-GRM")
 })
